@@ -18,6 +18,7 @@ from itertools import (
 )
 import more_itertools
 from typing import (
+    Callable,
     Iterable,
     Optional,
     TypeVar,
@@ -44,6 +45,15 @@ def filter_none(items: Iterable[Optional[_T]]) -> Iterable[_T]:
     return (i for i in items if i is not None)
 
 
+def find_first(
+    criteria: Callable[[_T], bool], items: Iterable[_T]
+) -> Optional[_T]:
+    for item in items:
+        if criteria(item):
+            return item
+    return None
+
+
 def squash(items: Iterable[Cmd[_T]]) -> Iterable[_T]:
     for item in items:
         yield unsafe_unwrap(item)
