@@ -6,6 +6,7 @@ from dataclasses import (
     dataclass,
 )
 from fa_purity.frozen import (
+    freeze,
     FrozenDict,
     FrozenList,
 )
@@ -16,8 +17,8 @@ from fa_purity.json.errors.invalid_type import (
     InvalidType,
 )
 from fa_purity.json.primitive.core import (
+    NotNonePrimTvar,
     Primitive,
-    PrimitiveTVar,
 )
 from fa_purity.json.primitive.factory import (
     to_primitive as _to_primitive,
@@ -65,10 +66,15 @@ class Unfolder:
         return self.to_json().alt(Exception).bind(lambda d: try_get(d, key))
 
     def to_primitive(
-        self, prim_type: Type[PrimitiveTVar]
-    ) -> Result[PrimitiveTVar, InvalidType]:
+        self, prim_type: Type[NotNonePrimTvar]
+    ) -> Result[NotNonePrimTvar, InvalidType]:
         return _to_primitive(self.value, prim_type)
 
+    def to_none(self) -> Result[None, InvalidType]:
+        if self.value is None:
+            return Result.success(self.value)
+        return Result.failure(invalid_type.new("to_none", "None", self.value))
+
     def to_list(self) -> UnfoldResult[FrozenList[JsonValue]]:
         if isinstance(self.value, tuple):
             return Result.success(self.value)
@@ -82,15 +88,15 @@ class Unfolder:
         return self.to_list().map(inr)
 
     def to_list_of(
-        self, prim_type: Type[PrimitiveTVar]
-    ) -> UnfoldResult[FrozenList[PrimitiveTVar]]:
+        self, prim_type: Type[NotNonePrimTvar]
+    ) -> UnfoldResult[FrozenList[NotNonePrimTvar]]:
         try:
             return self.to_list().map(
                 lambda l: tuple(
                     _to_primitive(i.unfold(), prim_type).unwrap() for i in l
                 )
             )
-        except UnwrapError[PrimitiveTVar, InvalidType]:
+        except UnwrapError[NotNonePrimTvar, InvalidType]:
             return Result.failure(
                 invalid_type.new(
                     "to_list_of", f"FrozenList[{prim_type}]", prim_type
@@ -109,9 +115,16 @@ class Unfolder:
             )
         )
 
+    def to_unfolder_dict(self) -> UnfoldResult[FrozenDict[str, Unfolder]]:
+        return (
+            self.to_json()
+            .map(lambda d: {k: Unfolder(v) for k, v in d.items()})
+            .map(freeze)
+        )
+
     def to_dict_of(
-        self, prim_type: Type[PrimitiveTVar]
-    ) -> UnfoldResult[FrozenDict[str, PrimitiveTVar]]:
+        self, prim_type: Type[NotNonePrimTvar]
+    ) -> UnfoldResult[FrozenDict[str, NotNonePrimTvar]]:
         try:
             return self.to_json().map(
                 lambda d: FrozenDict(
@@ -121,7 +134,7 @@ class Unfolder:
                     }
                 )
             )
-        except UnwrapError[PrimitiveTVar, InvalidType]:
+        except UnwrapError[NotNonePrimTvar, InvalidType]:
             return Result.failure(
                 invalid_type.new(
                     f"to_dict_of", f"Dict[str, {prim_type}]", self.value
