@@ -14,6 +14,9 @@ from fa_purity.cmd import (
 from fa_purity.frozen import (
     FrozenList,
 )
+from fa_purity.maybe import (
+    Maybe,
+)
 import functools
 from typing import (
     Callable,
@@ -54,6 +57,11 @@ class Stream(_Stream[_T]):
         )
         return Stream(draft)
 
+    def find_first(self, criteria: Callable[[_T], bool]) -> Cmd[Maybe[_T]]:
+        return self._new_iter.map(
+            lambda i: _iter_factory.find_first(criteria, i)
+        ).map(Maybe.from_optional)
+
     def chunked(self, size: int) -> Stream[FrozenList[_T]]:
         draft = _Stream(
             self._new_iter.map(lambda i: _iter_factory.chunked(i, size))
